@@ -73,7 +73,7 @@ def uv_in_uvfits(paper_miriad, tmp_path):
 def test_read_write_read_atca(tmp_path, future_shapes):
     uv_in = UVData()
     uv_out = UVData()
-    atca_file = os.path.join(DATA_PATH, "atca_miriad")
+    atca_file = os.path.join(DATA_PATH, "atca_miriad/")
     testfile = os.path.join(tmp_path, "outtest_atca_miriad.uv")
     with uvtest.check_warnings(
         UserWarning,
@@ -102,6 +102,12 @@ def test_read_write_read_atca(tmp_path, future_shapes):
     if future_shapes:
         uv_out.use_future_array_shapes()
 
+    # make sure filename is what we expect
+    assert uv_in.filename[0] == "atca_miriad"
+    assert uv_out.filename[0] == "outtest_atca_miriad.uv"
+    assert len(uv_in.filename) == len(uv_out.filename)
+    uv_in.filename = uv_out.filename
+
     assert uv_in == uv_out
 
 
@@ -114,69 +120,42 @@ def test_read_nrao_write_miriad_read_miriad(casa_uvfits, tmp_path):
     writefile = os.path.join(tmp_path, "outtest_miriad.uv")
     uvfits_uv.write_miriad(writefile, clobber=True)
     miriad_uv.read(writefile)
+
+    # make sure filename is what we expect
+    assert uvfits_uv.filename[0] == "day2_TDEM0003_10s_norx_1src_1spw.uvfits"
+    assert miriad_uv.filename[0] == "outtest_miriad.uv"
+    assert len(uvfits_uv.filename) == len(miriad_uv.filename)
+    uvfits_uv.filename = miriad_uv.filename
+
     assert uvfits_uv == miriad_uv
 
 
-@pytest.mark.filterwarnings("ignore:Telescope SZA is not in known_telescopes.")
+@pytest.mark.filterwarnings("ignore:LST values stored in this file are not ")
 @pytest.mark.filterwarnings("ignore:The uvw_array does not match the expected values")
-@pytest.mark.filterwarnings("ignore:Telescope location is set at sealevel")
 def test_read_write_read_carma(tmp_path):
     uv_in = UVData()
     uv_out = UVData()
     carma_file = os.path.join(DATA_PATH, "carma_miriad")
     testfile = os.path.join(tmp_path, "outtest_carma_miriad.uv")
 
-    # Test file is multi-source, make sure it bugs out
-    pytest.raises(
-        NotImplementedError, uv_in.read, carma_file,
-    )
-
     with uvtest.check_warnings(
         UserWarning,
         [
-            "Altitude is not present in Miriad file, and "
-            "telescope SZA is not in known_telescopes. ",
-            "Altitude is not present",
-            "Telescope location is set at sealevel at the file lat/lon "
-            "coordinates. Antenna positions are present, but the mean antenna "
-            "position does not give a telescope_location on the surface of the "
-            "earth. Antenna positions do not appear to be on the surface of the "
-            "earth and will be treated as relative.",
-            "Telescope SZA is not in known_telescopes.",
-            "File containts more than one source, only using data where source = NOISE",
-            "drift RA, Dec is off from lst, latitude by more than 1.0 deg",
+            "Altitude is not present in Miriad file, "
+            "using known location values for SZA.",
             "The uvw_array does not match the expected values given the antenna "
             "positions.",
-            "antaz in extra_keywords is a list, array or dict",
-            "antel in extra_keywords is a list, array or dict",
-            "axisoff in extra_keywords is a list, array or dict",
-            "cable in extra_keywords is a list, array or dict",
-            "dazim in extra_keywords is a list, array or dict",
-            "delev in extra_keywords is a list, array or dict",
-            "jyperka in extra_keywords is a list, array or dict",
             "pamatten in extra_keywords is a list, array or dict",
-            "phaselo1 in extra_keywords is a list, array or dict",
-            "phaselo2 in extra_keywords is a list, array or dict",
-            "phasem1 in extra_keywords is a list, array or dict",
-            "themt in extra_keywords is a list, array or dict",
-            "wfreq in extra_keywords is a list, array or dict",
-            "wwidth in extra_keywords is a list, array or dict",
-            "wsystemp in extra_keywords is a list, array or dict",
             "psys in extra_keywords is a list, array or dict",
             "psysattn in extra_keywords is a list, array or dict",
             "ambpsys in extra_keywords is a list, array or dict",
             "bfmask in extra_keywords is a list, array or dict",
-            "wcorr in extra_keywords is a list, array or dict",
+            "Cannot fix the phases of multi phase center datasets, as they were not "
+            "supported when the old phasing method was used, and thus, there "
+            "is no need to correct the data.",
         ],
     ):
-        uv_in.read(carma_file, skip_extra_sources=True)
-
-    # Spoofing these values for now, since the data is from the noise source, which
-    # doesn't neccessarily have correct values
-    uv_in._set_phased()
-    uv_in.phase_center_ra = 0.0
-    uv_in.phase_center_dec = 0.0
-    uv_in.phase_center_epoch = 2000.0
+        uv_in.read(carma_file, fix_old_proj=True)
 
     # Extra keywords cannnot handle lists, dicts, or arrays, so drop them from the
     # dataset, so that the writer doesn't run into issues.
@@ -190,11 +169,142 @@ def test_read_write_read_carma(tmp_path):
             uv_in.extra_keywords.pop(item)
 
     uv_in.write_miriad(testfile, clobber=True)
+    uv_out.read(testfile)
 
+    # make sure filename is what we expect
+    assert uv_in.filename == ["carma_miriad"]
+    assert uv_out.filename == ["outtest_carma_miriad.uv"]
+    uv_in.filename = uv_out.filename
+
+    assert uv_in == uv_out
+
+    # We should get the same result if we feed in these parameters, since the original
+    # file had the LST calculated on read, and its def a phased dataset
+    uv_out.read(testfile, calc_lst=False, phase_type="phased")
+
+    assert uv_in == uv_out
+
+    uv_in.write_miriad(testfile, clobber=True, calc_lst=True)
+    uv_out.read(testfile, calc_lst=False)
+
+    # Finally, make sure that if we calc LSTs on write, but not read, that we still
+    # get the same answer.
+    assert uv_in == uv_out
+
+
+@pytest.mark.filterwarnings("ignore:pamatten in extra_keywords is a list, array")
+@pytest.mark.filterwarnings("ignore:psys in extra_keywords is a list, array or dict")
+@pytest.mark.filterwarnings("ignore:psysattn in extra_keywords is a list, array or")
+@pytest.mark.filterwarnings("ignore:ambpsys in extra_keywords is a list, array or dict")
+@pytest.mark.filterwarnings("ignore:bfmask in extra_keywords is a list, array or dict")
+@pytest.mark.filterwarnings("ignore:LST values stored in this file are not ")
+@pytest.mark.filterwarnings("ignore:The uvw_array does not match the expected values")
+def test_read_carma_miriad_write_ms(tmp_path):
+    """
+    Check a roundtrip between CARMA-MIRIAD and MS formats.
+
+    Note that this check does a few different operations -- these are consolidated into
+    one test because several of them rely upon manipulating the same file object.
+    """
+    pytest.importorskip("casacore")
+    from casacore import tables
+
+    uv_in = UVData()
+    uv_out = UVData()
+    carma_file = os.path.join(DATA_PATH, "carma_miriad")
+    testfile = os.path.join(tmp_path, "outtest_carma_miriad.ms")
+
+    with uvtest.check_warnings(
+        UserWarning,
+        [
+            "Altitude is not present in Miriad file, "
+            "using known location values for SZA.",
+            "The uvw_array does not match the expected values given the antenna "
+            "positions.",
+            "pamatten in extra_keywords is a list, array or dict",
+            "psys in extra_keywords is a list, array or dict",
+            "psysattn in extra_keywords is a list, array or dict",
+            "ambpsys in extra_keywords is a list, array or dict",
+            "bfmask in extra_keywords is a list, array or dict",
+            "Cannot fix the phases of multi phase center datasets, as they were not "
+            "supported when the old phasing method was used, and thus, there "
+            "is no need to correct the data.",
+        ],
+    ):
+        uv_in.read(carma_file, fix_old_proj=True)
+
+    # MIRIAD is missing these in the file, so we'll fill it in here.
+    uv_in.antenna_diameters = np.zeros(uv_in.Nants_telescope)
+    uv_in.antenna_diameters[:6] = 10.0
+    uv_in.antenna_diameters[15:] = 3.5
+
+    # We need to recalculate app coords here for one source ("NOISE"), which was
+    # not actually correctly calculated in the online CARMA system (long story). Since
+    # the MS format requires recalculating apparent coords after read in, we'll
+    # calculate them here just to verify that everything matches.
+    uv_in._set_app_coords_helper()
+    uv_in.write_ms(testfile, clobber=True)
+    uv_out.read(testfile)
+
+    # Make sure the MS extra keywords are as expected
+    assert uv_out.extra_keywords["DATA_COL"] == "DATA"
+    assert uv_out.extra_keywords["observer"] == "SZA"
+    uv_in.extra_keywords["DATA_COL"] = "DATA"
+    uv_in.extra_keywords["observer"] = "SZA"
+
+    # make sure filename is what we expect
+    assert uv_in.filename == ["carma_miriad"]
+    assert uv_out.filename == ["outtest_carma_miriad.ms"]
+    uv_in.filename = uv_out.filename
+
+    # Do a quick check on the history to verify they're different.
+    assert uv_in.history != uv_out.history
+    uv_in.history = uv_out.history
+
+    # Final equality check
+    assert uv_in == uv_out
+
+    # Manipulate the table so that all fields have the same name (as is permitted
+    # for MS files), and wipe out the source_ID information
+    tb_field = tables.table(os.path.join(testfile, "FIELD"), ack=False, readonly=False)
+    orig_name = tb_field.getcol("NAME")
+    tb_field.putcol("NAME", ["TEST"] * 3)
+    tb_field.removecols("SOURCE_ID")
+    tb_field.close()
+
+    # Check and see that the naming convention lines up as expected -- only the internal
+    # catalog entries (specifically the names/keys and catalog IDs) should have changed.
+    uv_out.read(testfile)
+    cat_id_dict = {}
+    for idx in range(3):
+        sou_dict = uv_out.phase_center_catalog.pop("TEST-%03i" % idx)
+        sou_dict["cat_id"] = uv_in.phase_center_catalog[orig_name[idx]]["cat_id"]
+        uv_out.phase_center_catalog[orig_name[idx]] = sou_dict
+        cat_id_dict[idx] = uv_in.phase_center_catalog[orig_name[idx]]["cat_id"]
+
+    uv_out.phase_center_id_array = np.array(
+        [cat_id_dict[key] for key in uv_out.phase_center_id_array], dtype=int
+    )
+
+    # Final equality check
+    assert uv_in == uv_out
+
+    # Last but not least, change the coord system so that the catalog frames are the
+    # same as phase_center_frame
+    uv_in.phase_center_frame = "fk5"
+    uv_in._set_app_coords_helper()
+
+    # Check to make sure we raise an error if overwritting a file w/o clobber enabled
+    with pytest.raises(OSError, match="File exists; skipping"):
+        uv_in.write_ms(testfile, clobber=False)
+
+    # Do one last read/write/check for equality
+    uv_in.write_ms(testfile, clobber=True)
     uv_out.read(testfile)
     assert uv_in == uv_out
 
 
+@pytest.mark.filterwarnings("ignore:LST values stored in this file are not ")
 @pytest.mark.filterwarnings("ignore:The uvw_array does not match the expected values")
 def test_read_miriad_write_uvfits(uv_in_uvfits):
     """
@@ -207,6 +317,12 @@ def test_read_miriad_write_uvfits(uv_in_uvfits):
 
     miriad_uv.write_uvfits(testfile, spoof_nonessential=True, force_phase=True)
     uvfits_uv.read_uvfits(testfile)
+
+    # make sure filename is what we expect
+    assert miriad_uv.filename == ["zen.2456865.60537.xy.uvcRREAA"]
+    assert uvfits_uv.filename == ["outtest_miriad.uvfits"]
+    miriad_uv.filename = uvfits_uv.filename
+
     assert miriad_uv == uvfits_uv
 
 
@@ -266,15 +382,6 @@ def test_read_miriad_phasing_errors(err_type, read_kwargs, err_msg):
         miriad_uv.read(paper_miriad_file, **read_kwargs)
 
 
-@pytest.mark.filterwarnings("ignore:The uvw_array does not match the expected values")
-def test_read_miriad_write_uvfits_phasing_error(uv_in_uvfits):
-    miriad_uv, uvfits_uv, testfile = uv_in_uvfits
-
-    miriad_uv._set_unknown_phase_type()
-    with pytest.raises(ValueError, match="The phasing type of the data is unknown"):
-        miriad_uv.write_uvfits(testfile, spoof_nonessential=True)
-
-
 @pytest.mark.filterwarnings("ignore:The uvw_array does not match the expected values")
 def test_wronglatlon():
     """
@@ -619,6 +726,12 @@ def test_singletimeselect_drift(uv_in_paper, tmp_path):
     uv_in.select(times=uv_in.time_array[0])
     uv_in.write_miriad(testfile, clobber=True)
     uv_out.read(testfile)
+
+    # make sure filename is what we expect
+    assert uv_in.filename == ["zen.2456865.60537.xy.uvcRREAA"]
+    assert uv_out.filename == ["outtest_miriad.uv"]
+    uv_in.filename = uv_out.filename
+
     assert uv_in == uv_out
 
     # check that setting the phase_type works
@@ -635,6 +748,12 @@ def test_singletimeselect_drift(uv_in_paper, tmp_path):
 
     uv_in_copy.write_miriad(testfile, clobber=True)
     uv_out.read(testfile)
+
+    # make sure filename is what we expect
+    assert uv_in_copy.filename == ["zen.2456865.60537.xy.uvcRREAA"]
+    assert uv_out.filename == ["outtest_miriad.uv"]
+    uv_in_copy.filename = uv_out.filename
+
     assert uv_in_copy == uv_out
 
     # check that setting the phase_type works
@@ -746,6 +865,11 @@ def test_miriad_extra_keywords(uv_in_paper, tmp_path, kwd_names, kwd_values):
     uv_in.write_miriad(testfile, clobber=True)
     uv_out.read(testfile)
 
+    # make sure filename is what we expect
+    assert uv_in.filename == ["zen.2456865.60537.xy.uvcRREAA"]
+    assert uv_out.filename == ["outtest_miriad.uv"]
+    uv_in.filename = uv_out.filename
+
     assert uv_in == uv_out
 
 
@@ -759,6 +883,11 @@ def test_roundtrip_optional_params(uv_in_paper, tmp_path):
     uv_in.write_miriad(testfile, clobber=True)
     uv_out.read(testfile)
 
+    # make sure filename is what we expect
+    assert uv_in.filename == ["zen.2456865.60537.xy.uvcRREAA"]
+    assert uv_out.filename == ["outtest_miriad.uv"]
+    uv_in.filename = uv_out.filename
+
     assert uv_in == uv_out
 
     # test with bda as well (single entry in tuple)
@@ -815,6 +944,11 @@ def test_read_write_read_miriad(uv_in_paper):
     uv_in, uv_out, write_file = uv_in_paper
     uv_out.read(write_file)
 
+    # make sure filename is what we expect
+    assert uv_in.filename == ["zen.2456865.60537.xy.uvcRREAA"]
+    assert uv_out.filename == ["outtest_miriad.uv"]
+    uv_in.filename = uv_out.filename
+
     assert uv_in == uv_out
 
     # check that we can read & write phased data
@@ -847,6 +981,12 @@ def test_miriad_antenna_diameters(uv_in_paper):
     )
     uv_in.write_miriad(write_file, clobber=True)
     uv_out.read(write_file)
+
+    # make sure that filenames make sense
+    assert uv_in.filename == ["zen.2456865.60537.xy.uvcRREAA"]
+    assert uv_out.filename == ["outtest_miriad.uv"]
+    uv_in.filename = uv_out.filename
+
     assert uv_in == uv_out
 
     # check that antenna diameters get written if not exactly float
@@ -876,15 +1016,6 @@ def test_miriad_antenna_diameters(uv_in_paper):
     assert uv_in == uv_out
 
 
-@pytest.mark.filterwarnings("ignore:The uvw_array does not match the expected values")
-def test_miriad_write_miriad_unkonwn_phase_error(uv_in_paper):
-    uv_in, uv_out, write_file = uv_in_paper
-    # check that trying to write a file with unknown phasing raises an error
-    uv_in._set_unknown_phase_type()
-    with pytest.raises(ValueError, match="The phasing type of the data is unknown"):
-        uv_in.write_miriad(write_file, clobber=True)
-
-
 @pytest.mark.filterwarnings("ignore:The uvw_array does not match the expected values")
 def test_miriad_write_read_diameters(tmp_path):
     uv_in = UVData()
@@ -896,6 +1027,12 @@ def test_miriad_write_read_diameters(tmp_path):
     uv_in.read(testfile_diameters)
     uv_in.write_miriad(write_file, clobber=True)
     uv_out.read(write_file)
+
+    # make sure filenames are what we expect
+    assert uv_in.filename == ["zen.2457698.40355.xx.HH.uvcA"]
+    assert uv_out.filename == ["outtest_miriad.uv"]
+    uv_in.filename = uv_out.filename
+
     assert uv_in == uv_out
 
 
@@ -940,6 +1077,12 @@ def test_miriad_integration_time_precision(uv_in_paper):
     uv_in.write_miriad(write_file, clobber=True)
     new_uv = UVData()
     new_uv.read(write_file)
+
+    # make sure filenames are what we expect
+    assert uv_in.filename == ["zen.2456865.60537.xy.uvcRREAA"]
+    assert new_uv.filename == ["outtest_miriad.uv"]
+    uv_in.filename = new_uv.filename
+
     assert uv_in == new_uv
 
 
@@ -971,6 +1114,12 @@ def test_read_write_read_miriad_partial_bls(uv_in_paper, select_kwargs, tmp_path
         bls = [bls]
     assert np.all([bl[:2] in antpairs or bl[:2][::-1] in antpairs for bl in bls])
     exp_uv = full.select(inplace=False, **select_kwargs)
+
+    # make sure filenames are what we expect
+    assert uv_in.filename == ["outtest_miriad.uv"]
+    assert exp_uv.filename == ["zen.2456865.60537.xy.uvcRREAA"]
+    uv_in.filename = exp_uv.filename
+
     assert uv_in == exp_uv
 
 
@@ -988,6 +1137,12 @@ def test_read_write_read_miriad_partial_antenna_nums(uv_in_paper, tmp_path):
     exp_uv = full.select(antenna_nums=[0], inplace=False)
     assert np.max(exp_uv.ant_1_array) == 0
     assert np.max(exp_uv.ant_2_array) == 0
+
+    # make sure filenames are what we expect
+    assert uv_in.filename == ["outtest_miriad.uv"]
+    assert exp_uv.filename == ["zen.2456865.60537.xy.uvcRREAA"]
+    uv_in.filename = exp_uv.filename
+
     assert uv_in == exp_uv
 
 
@@ -1019,6 +1174,12 @@ def test_read_write_read_miriad_partial_times(uv_in_paper, select_kwargs, tmp_pa
     # time range with selecting on exact times
     select_kwargs.pop("time_range", None)
     exp_uv = full.select(times=full_times, inplace=False, **select_kwargs)
+
+    # make sure filenames are what we expect
+    assert uv_in.filename == ["outtest_miriad.uv"]
+    assert exp_uv.filename == ["zen.2456865.60537.xy.uvcRREAA"]
+    uv_in.filename = exp_uv.filename
+
     assert uv_in == exp_uv
 
 
@@ -1035,6 +1196,12 @@ def test_read_write_read_miriad_partial_pols(uv_in_paper, pols, tmp_path):
     uv_in.read(write_file, polarizations=pols)
     assert full.polarization_array == uv_in.polarization_array
     exp_uv = full.select(polarizations=pols, inplace=False)
+
+    # make sure filenames are what we expect
+    assert uv_in.filename == ["outtest_miriad.uv"]
+    assert exp_uv.filename == ["zen.2456865.60537.xy.uvcRREAA"]
+    uv_in.filename = exp_uv.filename
+
     assert uv_in == exp_uv
 
 
@@ -1049,14 +1216,32 @@ def test_read_write_read_miriad_partial_ant_str(uv_in_paper, tmp_path):
     uv_in.read(write_file, ant_str="auto")
     assert np.array([blp[0] == blp[1] for blp in uv_in.get_antpairs()]).all()
     exp_uv = full.select(ant_str="auto", inplace=False)
+
+    # make sure filenames are what we expect
+    assert uv_in.filename == ["outtest_miriad.uv"]
+    assert exp_uv.filename == ["zen.2456865.60537.xy.uvcRREAA"]
+    uv_in.filename = exp_uv.filename
+
     assert uv_in == exp_uv
 
     uv_in.read(write_file, ant_str="cross")
     assert np.array([blp[0] != blp[1] for blp in uv_in.get_antpairs()]).all()
     exp_uv = full.select(ant_str="cross", inplace=False)
+
+    # make sure filenames are what we expect
+    assert uv_in.filename == ["outtest_miriad.uv"]
+    assert exp_uv.filename == ["zen.2456865.60537.xy.uvcRREAA"]
+    uv_in.filename = exp_uv.filename
+
     assert uv_in == exp_uv
 
     uv_in.read(write_file, ant_str="all")
+
+    # make sure filenames are what we expect
+    assert uv_in.filename == ["outtest_miriad.uv"]
+    assert exp_uv.filename == ["zen.2456865.60537.xy.uvcRREAA"]
+    uv_in.filename = exp_uv.filename
+
     assert uv_in == full
 
 
@@ -1130,6 +1315,11 @@ def test_read_write_read_miriad_partial_ant_str(uv_in_paper, tmp_path):
             {"polarizations": ["yy"]},
             "No data is present, probably as a result of select on read",
         ),
+        (
+            ValueError,
+            {"polarizations": [-9]},
+            "No polarizations in data matched input",
+        ),
         (
             ValueError,
             {"time_range": "foo"},
@@ -1192,6 +1382,12 @@ def test_read_write_read_miriad_partial_with_warnings(uv_in_paper, tmp_path):
         uv_in.read(write_file, times=times_to_keep)
 
     exp_uv = full.select(times=times_to_keep, inplace=False)
+
+    # make sure filenames are what we expect
+    assert uv_in.filename == ["outtest_miriad.uv"]
+    assert exp_uv.filename == ["zen.2456865.60537.xy.uvcRREAA"]
+    uv_in.filename = exp_uv.filename
+
     assert uv_in == exp_uv
 
     uv_in = UVData()
@@ -1210,6 +1406,12 @@ def test_read_write_read_miriad_partial_with_warnings(uv_in_paper, tmp_path):
     ):
         uv_in.read(write_file, blt_inds=blts_select, antenna_nums=ants_keep)
     exp_uv = full.select(blt_inds=blts_select, antenna_nums=ants_keep, inplace=False)
+
+    # make sure filenames are what we expect
+    assert uv_in.filename == ["outtest_miriad.uv"]
+    assert exp_uv.filename == ["zen.2456865.60537.xy.uvcRREAA"]
+    uv_in.filename = exp_uv.filename
+
     assert uv_in != exp_uv
 
 
@@ -1251,6 +1453,13 @@ def test_read_write_read_miriad_partial_metadata_only(uv_in_paper, tmp_path):
 
     assert uv_in.history != uv_in2.history
     uv_in2.history = uv_in.history
+
+    # make sure filenames are what we expect
+    assert uv_in.filename == ["zen.2456865.60537.xy.uvcRREAA"]
+    assert set(uv_in2.filename) == {"outtest_miriad.uv", "outtest_miriad2.uv"}
+    uv_in2.filename = uv_in.filename
+    uv_in2._filename.form = (1,)
+
     assert uv_in == uv_in2
 
 
@@ -1271,6 +1480,11 @@ def test_read_ms_write_miriad_casa_history(tmp_path):
     ms_uv.write_miriad(testfile, clobber=True)
     miriad_uv.read(testfile)
 
+    # make sure filenames are what we expect
+    assert miriad_uv.filename == ["outtest_miriad"]
+    assert ms_uv.filename == ["day2_TDEM0003_10s_norx_1src_1spw.ms"]
+    miriad_uv.filename = ms_uv.filename
+
     assert miriad_uv == ms_uv
 
 
@@ -1292,6 +1506,11 @@ def test_rwr_miriad_antpos_issues(uv_in_paper, tmp_path):
     ):
         uv_out.read(write_file, run_check=False)
 
+    # make sure filenames are what we expect
+    assert uv_in_copy.filename == ["zen.2456865.60537.xy.uvcRREAA"]
+    assert uv_out.filename == ["outtest_miriad.uv"]
+    uv_in_copy.filename = uv_out.filename
+
     assert uv_in_copy == uv_out
 
     uv_in_copy = uv_in.copy()
@@ -1309,6 +1528,11 @@ def test_rwr_miriad_antpos_issues(uv_in_paper, tmp_path):
     ):
         uv_out.read(write_file)
 
+    # make sure filenames are what we expect
+    assert uv_in_copy.filename == ["zen.2456865.60537.xy.uvcRREAA"]
+    assert uv_out.filename == ["outtest_miriad.uv"]
+    uv_in_copy.filename = uv_out.filename
+
     assert uv_in_copy == uv_out
 
     uv_in.antenna_positions = None
@@ -1328,6 +1552,11 @@ def test_rwr_miriad_antpos_issues(uv_in_paper, tmp_path):
     ):
         uv_out.read(write_file, run_check=False)
 
+    # make sure filenames are what we expect
+    assert uv_in.filename == ["zen.2456865.60537.xy.uvcRREAA"]
+    assert uv_out.filename == ["outtest_miriad.uv"]
+    uv_in.filename = uv_out.filename
+
     assert uv_in == uv_out
 
 
@@ -1363,6 +1592,13 @@ def test_multi_files(casa_uvfits, tmp_path):
         uv1.history,
     )
     uv1.history = uv_full.history
+
+    # make sure filenames are what we expect
+    assert set(uv1.filename) == {"uv1", "uv2"}
+    assert uv_full.filename == ["day2_TDEM0003_10s_norx_1src_1spw.uvfits"]
+    uv1.filename = uv_full.filename
+    uv1._filename.form = (1,)
+
     assert uv1 == uv_full
 
     # again, setting axis
@@ -1378,6 +1614,13 @@ def test_multi_files(casa_uvfits, tmp_path):
         uv1.history,
     )
     uv1.history = uv_full.history
+
+    # make sure filenames are what we expect
+    assert set(uv1.filename) == {"uv1", "uv2"}
+    assert uv_full.filename == ["day2_TDEM0003_10s_norx_1src_1spw.uvfits"]
+    uv1.filename = uv_full.filename
+    uv1._filename.form = (1,)
+
     assert uv1 == uv_full
 
 
@@ -1467,3 +1710,69 @@ def test_file_with_bad_extra_words():
     # The antenna positions is (0, 0, 0) vector
     with uvtest.check_warnings(warn_category, warn_message):
         uv.read_miriad(fname, run_check=False)
+
+
+@pytest.mark.filterwarnings("ignore:The original `phase` method is deprecated")
+def test_fix_phase(tmp_path):
+    uv_in = UVData()
+    uv_out = UVData()
+    filepath = os.path.join(DATA_PATH, "zen.2456865.60537.xy.uvcRREAA")
+    writepath = os.path.join(tmp_path, "phasetest.miriad")
+    with uvtest.check_warnings(
+        UserWarning,
+        [
+            "Altitude is not present in Miriad file,"
+            " using known location values for PAPER.",
+            "The uvw_array does not match the expected"
+            " values given the antenna positions.",
+        ],
+    ):
+        uv_in.read(filepath)
+
+    # UVWs don't seem to line up w/ what we expect on read, so remedy this now.
+    uv_in.set_uvws_from_antenna_positions()
+
+    # Make some copies of the data
+    uv_in_bad_ant = uv_in.copy()
+    uv_in_bad_base = uv_in.copy()
+
+    # These values could be anything -- we're just picking something that we know should
+    # be visible from the telescope at the time of obs (ignoring horizon limits).
+    phase_ra = uv_in.lst_array[0]
+    phase_dec = uv_in.telescope_location_lat_lon_alt[0] * 0.5
+
+    # Do the improved phasing on the dat set.
+    uv_in.phase(phase_ra, phase_dec)
+
+    # First test the case where we are using the old phase method with the uvws
+    # calculated from the antenna positions
+    uv_in_bad_ant.phase(phase_ra, phase_dec, use_old_proj=True, use_ant_pos=True)
+    uv_in_bad_ant.write_miriad(
+        writepath, clobber=True, run_check=False, check_extra=False
+    )
+    uv_out.read(writepath, fix_old_proj=True, fix_use_ant_pos=True)
+
+    # make sure filenames are what we expect
+    assert uv_in.filename == ["zen.2456865.60537.xy.uvcRREAA"]
+    assert uv_out.filename == ["phasetest.miriad"]
+    uv_in.filename = uv_out.filename
+
+    assert uv_in == uv_out
+
+    # Now test and see what happens if we use the baseline-vector based version of the
+    # phasing method.
+    uv_in_bad_base.phase(phase_ra, phase_dec, use_old_proj=True, use_ant_pos=False)
+    uv_in_bad_base.write_miriad(
+        writepath, clobber=True, run_check=False, check_extra=False
+    )
+    uv_out.read(writepath, fix_old_proj=True, fix_use_ant_pos=False)
+    # We have to handle this case a little carefully, because since the old
+    # unphase_to_drift was _mostly_ accurate, although it does seem to intoduce errors
+    # on the order of a part in 1e5, which translates to about a tenth of a degree phase
+    # error in the test data set used here. Check that first, make sure it's good
+    assert np.allclose(uv_in.data_array, uv_out.data_array, rtol=3e-4)
+
+    # Once we know the data are okay, copy over data array and check for equality btw
+    # the other attributes of the two objects.
+    uv_out.data_array = uv_in.data_array
+    assert uv_in == uv_out
